@@ -3,8 +3,28 @@ import pandas as pd
 from tensorflow import keras
 from tensorflow.keras import Sequential
 
-from model_data_util.constant import OPTIONS, ONE_HOT_ENC, NUM_DIM
-from model_data_util.create_tt_data.generate_tt_data import createInputbyModel
+from model_data_util.constant import OPTIONS, ONE_HOT_ENC, NUM_DIM, DEFAULT_INPUT_SHAPE
+
+
+def createInputbyModel(model, data_points, data_shape=DEFAULT_INPUT_SHAPE):
+    """
+    Generate data according to model's conf
+    The input shape is set in default
+    """
+    last_dense_conf = {}
+    first_layer_conf = {}
+    for l_conf in model.get_config()['layers']:
+        if 'Dense' == l_conf['class_name']:
+            last_dense_conf = l_conf['config']
+        if first_layer_conf == {} and 'InputLayer' != l_conf['class_name']:
+            first_layer_conf = l_conf
+    assert last_dense_conf != {}
+    out_shape = last_dense_conf['units']
+    if first_layer_conf['class_name'] == 'Dense':
+        data_shape = [out_shape] if type(out_shape) == int else out_shape
+    x = np.ones((data_points, *data_shape))
+    y = np.ones((data_points, out_shape))
+    return (x, y)
 
 
 def convertModelToRawData(model, columns, num_data, num_dim=NUM_DIM):
@@ -29,8 +49,8 @@ def convertModelToRawData(model, columns, num_data, num_dim=NUM_DIM):
             out_shape = np.array(model.layers[i - 1].output.shape)
         elif i == 0 and l_name == "InputLayer":
             out_shape = np.array(conf['batch_input_shape'])
-        elif i == 0 and l_name != "inputlayer":
-            out_shape = createInputbyModel(model)[0].shape
+        elif i == 0 and l_name != "InputLayer":
+            out_shape = createInputbyModel(model, 1)[0].shape
         if out_shape is not None:
             assert out_shape.shape[0] <= num_dim
             for j in range(num_dim):
